@@ -64,9 +64,9 @@ void Audio::threadFinished()
 
     connect(music, SIGNAL(finished()), this, SLOT(audioFinished()));
 
-    this->wavCreated();
 
- //   reader->deleteLater();
+
+    reader->deleteLater();
 }
 
 void Audio::setAudio(QString filename)
