@@ -230,7 +230,7 @@ void MainWindow::article_selected(QTableWidgetItem *item)
 {
     message->setLabelText("Loading " + item->text());
     message->show();
-    bool existsAlready = QFile(QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation) +  item->text().toLower().normalized(QString::NormalizationForm_D).replace(" ", "_")+".txt").exists();
+    bool existsAlready = QFile("/home/user/MyDocs/.audiowiki/" +  item->text().toLower().normalized(QString::NormalizationForm_D).replace(" ", "_")+".txt").exists();
     network->retrieveArticle(item->text(), existsAlready);
 }
 
@@ -240,7 +240,7 @@ void MainWindow::openArticleFromLink(QListWidgetItem *item)
         player->hide();
     message->setLabelText("Loading " + item->text());
     message->show();
-    bool existsAlready = QFile(QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation) +  item->text().toLower().normalized(QString::NormalizationForm_D).replace(" ", "_")+".txt").exists();
+    bool existsAlready = QFile("/home/user/MyDocs/.audiowiki/" +  item->text().toLower().normalized(QString::NormalizationForm_D).replace(" ", "_")+".txt").exists();
     network->retrieveArticle(item->text(), existsAlready);
 }
 
@@ -248,7 +248,7 @@ void MainWindow::playlist_item_selected(QTreeWidgetItem *item, int column)
 {
     message->setLabelText("Opening " + item->text(column));
     message->show();
-    bool existsAlready = QFile(QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation) +  item->text(column).toLower().normalized(QString::NormalizationForm_D).replace(" ", "_")+".txt").exists();
+    bool existsAlready = QFile("/home/user/MyDocs/.audiowiki/" +  item->text(column).toLower().normalized(QString::NormalizationForm_D).replace(" ", "_")+".txt").exists();
     network->retrieveArticle(item->text(column), existsAlready);
 }
 
@@ -278,12 +278,10 @@ void MainWindow::playlist_selected(QList<QTreeWidgetItem *> items, int column)
             openPlaylist = false;
         else
             openPlaylist = true;*/
-        bool existsAlready = QFile(QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation) +  item->text(column).toLower().normalized(QString::NormalizationForm_D).replace(" ", "_")+".txt").exists();
+        bool existsAlready = QFile("/home/user/MyDocs/.audiowiki/" +  item->text(column).toLower().normalized(QString::NormalizationForm_D).replace(" ", "_")+".txt").exists();
         network->retrieveArticle(item->text(column), existsAlready);
 
     }
-    openPlaylist = false;
-    player->setPlaylistFocus();
 }
 
 void MainWindow::openArticleList(QList<QString> searchTitles)
@@ -309,9 +307,18 @@ void MainWindow::openArticleInPlayer(QString title, QString article)
      player->openArticle(title, article, openPlaylist);
      ui->playerButton->setDown(true);
      ui->mainWindowButton->setDown(false);
+
+
      if(!player->isVisible())
         player->show();
 
+     if (openPlaylist)
+     {
+         openPlaylist = false;
+         player->setPlaylistFocus();
+     }
+
+
      //message->hide();
 }
 
