@@ -26,10 +26,10 @@ Player::~Player()
 
 void Player::openArticle(QString itemName, QString text, bool playlist)
 {
-    path = QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation) + itemName.toLower().normalized(QString::NormalizationForm_D)+".txt";
+    path = "/home/user/MyDocs/.audiowiki/" + itemName.toLower().normalized(QString::NormalizationForm_D)+".txt";
 
     QStringList links;
-    QFile *articleLinks = new QFile(QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation) +  itemName.toLower().normalized(QString::NormalizationForm_D)+".dat");
+    QFile *articleLinks = new QFile("/home/user/MyDocs/.audiowiki/" +  itemName.toLower().normalized(QString::NormalizationForm_D)+".dat");
     if (articleLinks->open(QIODevice::ReadOnly))
     {
         QDataStream out(articleLinks);   // we will serialize the data into the file
@@ -63,12 +63,12 @@ void Player::openArticle(QString itemName, QString text, bool playlist)
 
 
     ui->articleBrowser->setText(text);
-    bool audioExists = QFile(QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation) +  itemName.toLower().normalized(QString::NormalizationForm_D)+".wav").exists();
+    bool audioExists = QFile("/home/user/MyDocs/.audiowiki/" +  itemName.toLower().normalized(QString::NormalizationForm_D)+".wav").exists();
 
     if (!playlist || !audioExists)
         audio->createWav(path);
     if (audioExists)
-        audio->setAudio(QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation) +  itemName.toLower().normalized(QString::NormalizationForm_D)+".wav");
+        audio->setAudio("/home/user/MyDocs/.audiowiki/" +  itemName.toLower().normalized(QString::NormalizationForm_D)+".wav");
 
     articleLoaded = true;
 
